@@ -1,7 +1,7 @@
 """entity classes for mailing-list entities
 
 :organization: Logilab
-:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -11,4 +11,4 @@ from cubicweb.entities import AnyEntity, fetch_config
 class MailingList(AnyEntity):
     """customized class for MailingList entities"""
     __regid__ = 'MailingList'
-    fetch_attrs, fetch_order = fetch_config(['name'])
+    fetch_attrs, cw_fetch_order = fetch_config(['name'])
