@@ -1,18 +1,18 @@
 """Specific views for mailinglists entities
 
 :organization: Logilab
-:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 
-from cubicweb.selectors import is_instance, score_entity
+from cubicweb.predicates import is_instance, score_entity
 from cubicweb.view import EntityView, EntityAdapter
 from cubicweb import tags
 from cubicweb.web import uicfg, action
 from cubicweb.web.views import primary, baseviews
 
 
-for attr in ('name', 'homepage', 'archive', 'mlid'):
+for attr in ('name', 'homepage', 'archive', 'mlid', 'email_address'):
     uicfg.primaryview_section.tag_attribute(('MailingList', attr), 'hidden')
 uicfg.primaryview_section.tag_subject_of(('MailingList', 'mailinglist_of', '*'),
                                          'sideboxes')
@@ -31,11 +31,10 @@ class MLPrimaryView(primary.PrimaryView):
         if entity.archive:
             self.w(u'<li>%s</li>' % tags.a(_('browse archives'),
                                            href=entity.archive))
-        self.w(u'<li>')
-        for email in entity.use_email:
-            self.w(u'%s :' % _('to post on the mailinglist'))
-            email.view('mailto', w=self.w)
-        self.w(u'</li>')
+        self.w(u'<li>%s %s</li>'
+               % (_('to post on the mailinglist:'),
+                  tags.a(entity.email_address,
+                         href=u'mailto:' + entity.email_address)))
         self.w(u'</ul>')
 
 
